# Examples

This section contains code examples to demonstrate what you can do with `kr8s`.

```{toctree}
creating_resources
listing_resources
inspecting_resources
modifying_resources
labelling_operator
```
